
/* Start: Bug 25143 - Form report is displayed incorrectly */
 
if exists (select * FROM SYS.OBJECTS WHERE object_id = object_id(N'[dbo].[cms_getformhistogramdatafortimeperiod]') and OBJECTPROPERTY(object_id, N'IsProcedure') = 1)
drop procedure [dbo].[cms_getformhistogramdatafortimeperiod]
go
CREATE PROCEDURE [dbo].[cms_getformhistogramdatafortimeperiod] 
	-- Add the parameters for the stored procedure here
(	@formid bigint,
	@dtDateStart datetime,
	@dtDateEnd datetime,
	@fields nvarchar(500),
	@languageid int=1033,
	@totalsubmit int OUTPUT
	)
AS
BEGIN
	-- SET NOCOUNT ON added to prevent extra result sets from
	-- interfering with SELECT statements.
	SET NOCOUNT ON;

	select @totalsubmit = count(distinct form_data_id) 
	from form_data_tbl 
	where (form_id = @formid) and content_language=@languageid and date_created>@dtDateStart and date_created<@dtDateEnd

	;with tmp( form_field_name, form_field_dataitem, form_field_value) as (
	select  form_field_name, LEFT(form_field_value, CHARINDEX(',',form_field_value+',')-1),
		STUFF(form_field_value, 1, CHARINDEX(',',form_field_value+','), '')
	from form_data_tbl 
	where (form_id = @formid) and content_language=@languageid and date_created>@dtDateStart and date_created<@dtDateEnd and (form_field_name in (select * from dbo.splitComma(@fields)))
	union all
	select form_field_name, LEFT(form_field_value, CHARINDEX(',',form_field_value+',')-1),
		STUFF(form_field_value, 1, CHARINDEX(',',form_field_value+','), '')
	from tmp
	where form_field_value > ''
	)
	select form_field_name, form_field_dataitem, count(form_field_dataitem) as totalhits
	from tmp
	group by form_field_name, form_field_dataitem
	order by form_field_name, form_field_dataitem

END
go

/* End: Bug 25143 - Form report is displayed incorrectly 
========================================================*/

/* Start: Escalation 25201 - Auto alias not removed after the taxonomy is removed from the content */

if exists (select 'x' from information_schema.routines where routine_schema='dbo' and 
			routine_type = 'procedure' and routine_name = 'cms_UrlAliasReGenContentTax')
drop procedure dbo.cms_UrlAliasReGenContentTax
go

create procedure dbo.cms_UrlAliasReGenContentTax
	@p_ContentId bigint,
	@p_LanguageId int
as
set nocount on
/*
	Regenerate aliases when content moves to new taxonomy
*/
begin
	declare @v_getnextno bigint;
	declare @v_rowcount int;

	create table #taxonomies_with_content 
	(
		taxonomy_id bigint,
		taxonomy_language_id int
	);

	create table #closest_config
	(
		urlaliasconfigid bigint
	);
	
	CREATE TABLE #taxonomy_rows
	(
		rowno int identity(1,1) not null,
		rowno2 bigint null,
		urlaliasconfigid bigint NOT NULL,
		urlaliasnm nvarchar(888) collate database_default NULL,
		urltargetnm nvarchar(255) collate database_default NULL,
		Languageid int NOT NULL,
		siteid bigint NOT NULL,
		targetid bigint NOT NULL,
		nodeid bigint NOT NULL,
		aliastypeid int NOT NULL,
		IsEnabled bit null
	);

	/* Get list of taxonomies where content_id exists */
	insert into #taxonomies_with_content (taxonomy_id, taxonomy_language_id)
	select	distinct 
			t.taxonomy_id, 
			t.taxonomy_language_id
	from dbo.content co
	INNER JOIN dbo.taxonomy_item_tbl AS ti
	 ON ti.taxonomy_item_id = co.content_id 
		AND ti.taxonomy_language_id = co.content_language
	inner join dbo.taxonomy_tbl t
	 on t.taxonomy_id = ti.taxonomy_id and
		t.taxonomy_language_id = ti.taxonomy_language_id 
	where co.content_id = @p_ContentId and co.content_language = @p_LanguageId;

	/*
	Work backwards through taxonomy hierarchy getting closest UrlConfigId's that contains
	content_id
	*/
	with tax_family (taxonomy_id, 
			taxonomy_parent_id,
			taxonomy_language_id,
			taxonomy_level)
	as
	(
	select child.taxonomy_id, 
			child.taxonomy_parent_id,
			child.taxonomy_language_id,
			0 as taxonomy_level  
		from dbo.taxonomy_tbl child
		 where exists(select 'x' 
						from #taxonomies_with_content tl 
						where tl.taxonomy_id = child.taxonomy_id and 
						tl.taxonomy_language_id = child.taxonomy_language_id)
	union all
	select ancestors.taxonomy_id, 
			ancestors.taxonomy_parent_id,
			ancestors.taxonomy_language_id,
			tf.taxonomy_level+1 
		from dbo.taxonomy_tbl ancestors
		inner join tax_family as tf
		 on (tf.taxonomy_parent_id = ancestors.taxonomy_id and 
			tf.taxonomy_language_id = ancestors.taxonomy_language_id and ancestors.taxonomy_id <> 0)
	)
	insert into #closest_config (UrlAliasConfigId)
	select ordered.UrlAliasConfigId 
	from (
		select cfg.urlaliasconfigid, tf.taxonomy_language_id,
		ROW_NUMBER() over (partition by cfg.urlaliasconfigid order by tf.taxonomy_level) ConfigOrder from tax_family tf
		inner join dbo.UrlAliasConfig cfg
		on cfg.SourceId = tf.taxonomy_id and 
			cfg.LanguageId = tf.taxonomy_language_id and 
			cfg.UrlAliasConfigTypeId = 1
		) ordered
	where ordered.ConfigOrder = 1;
	
	/*
		Generate taxonomy rows for content_id within the closest urlaliasconfigs
	*/
	insert into #taxonomy_rows (UrlAliasConfigId, urlaliasnm, urltargetnm, Languageid, SiteID, TargetID, NodeID, AliasTypeID, IsEnabled)
	select 	b.urlaliasconfigid,
		CASE	WHEN (b.PageTypeId = 1) THEN		
							dbo.cms_UrlAliasBldTaxonomy(a.taxonomy_path, d.content_title, fe.FileExtension,b.ExcludedPathId,b.LanguageId,b.urlaliasconfigid) 
				WHEN (b.PageTypeId = 2) THEN		
							dbo.cms_UrlAliasBldTaxonomy(a.taxonomy_path, CAST(d.content_id as varchar), fe.FileExtension,b.ExcludedPathId,b.LanguageId,b.urlaliasconfigid)
				WHEN (b.PageTypeId = 3)THEN		
							dbo.cms_UrlAliasBldTaxonomy(a.taxonomy_path, CAST(d.content_id as varchar) + '/' + CAST(d.content_language as varchar), fe.FileExtension,b.ExcludedPathId,b.LanguageId,b.urlaliasconfigid)
				ELSE
							dbo.cms_UrlAliasBldTaxonomy(a.taxonomy_path, d.content_title, fe.FileExtension,b.ExcludedPathId,b.LanguageId,b.urlaliasconfigid) 
		END as urlaliasnm,
		
		CASE 
			when tmpl.template_filename is not null and b.UseTemplate = 2 and ISNULL(b.SourceParmName,'') = '' AND CHARINDEX('?',tmpl.template_filename) > 0
				THEN stuff(f.filename,1,charindex(N'?',f.filename), tmpl.template_filename + N'&')
			WHEN tmpl.template_filename is not null and b.UseTemplate = 2 and ISNULL(b.SourceParmName,'') = '' AND CHARINDEX('?',tmpl.template_filename) = 0
				THEN stuff(f.filename,1,charindex(N'?',f.filename)-1,tmpl.template_filename)
			when tmpl.template_filename is not null and b.UseTemplate = 2 and ISNULL(b.SourceParmName,'') != '' AND CHARINDEX('?',tmpl.template_filename) > 0
				then dbo.BuildTaxonomyTargetLink(b.SourceParmName,a.taxonomy_id,stuff(f.filename,1,charindex(N'?',f.filename), tmpl.template_filename + N'&'))
			when tmpl.template_filename is not null and b.UseTemplate = 2 and ISNULL(b.SourceParmName,'') != '' AND CHARINDEX('?',tmpl.template_filename) = 0
				then dbo.BuildTaxonomyTargetLink(b.SourceParmName,a.taxonomy_id,(stuff(f.filename,1,charindex(N'?',f.filename)-1,tmpl.template_filename)))
			when b.UseTemplate = 1 and ISNULL(b.SourceParmName,'') != ''
				then dbo.BuildTaxonomyTargetLink(b.SourceParmName,a.taxonomy_id,f.filename)
			ELSE
				f.filename
		END
		as urltargetnm,
		
		d.content_language as Languageid,
		b.siteid, 
		   d.content_id as targetid,
		   a.taxonomy_id as nodeid,
		   b.UrlAliasConfigTypeId as aliastypeid,
		   IsEnabled
	FROM dbo.UrlAliasConfig b
	INNER JOIN #closest_config parents
		on parents.urlaliasconfigid = b.urlaliasconfigid
	INNER JOIN dbo.taxonomy_children_tbl tct 
				ON b.SourceId = tct.taxonomy_id
			   AND b.UrlAliasConfigTypeId = 1 
			   AND tct.taxonomy_language_id = b.LanguageId
	INNER JOIN dbo.taxonomy_tbl AS a 
	 on a.taxonomy_id = tct.taxonomy_child_id and 
		tct.taxonomy_language_id = a.taxonomy_language_id 
			INNER JOIN dbo.taxonomy_item_tbl AS c 
					ON a.taxonomy_id = c.taxonomy_id 
				   AND a.taxonomy_language_id = c.taxonomy_language_id 
			INNER JOIN dbo.content AS d 
					ON c.taxonomy_item_id = d.content_id 
				   AND c.taxonomy_language_id = d.content_language
				   and d.content_language = @p_LanguageId
				   and d.content_id = @p_ContentId 
			INNER JOIN dbo.content_folder_tbl AS e 
					ON d.folder_id = e.folder_id 
				   AND e.folder_type NOT IN (3,4)
			INNER JOIN dbo.library AS f 
					ON d.content_id = f.content_id 
				   AND d.content_language = f.content_language 
				   AND f.libtype_id NOT IN (1,3) 		
				   AND f.content_type NOT IN (7)
			inner join dbo.UrlAliasFileExtensions fe
			 on fe.FileExtensionId = b.FileExtensionId
			left outer join dbo.templates_tbl tmpl
			 on tmpl.template_id = a.template_id and 
				tmpl.content_language = a.taxonomy_language_id
			where b.IsDeleted = 0
	option (force order)
	;
	
	select @v_rowcount = count(*) from #taxonomy_rows;
	
	/* Delete pre-existing rows prior to reinsert */
	Delete from dbo.urlaliasmapping where targetid = @p_ContentId and aliastypeid = 1 and Languageid = @p_LanguageId;
		
	/*
		If there is nothing to map at this point get out and report. Better than changing MAX_ENTRIES pointer and failing there.
	*/
	if (@v_rowcount = 0) RETURN;
		
	exec cms_getnexttableid @tablename = 'urlaliasmapping', @batchsize = @v_rowcount, @newvalue = @v_getnextno output 
	
	-- offset for row_number() starting at 1
	set @v_getnextno = @v_getnextno - 1;
	
	update #taxonomy_rows set rowno2 = rowno+@v_getnextno;
	
	with CheckForDuplicateAliasName (UrlAliasMappingId, urlaliasnm)
	as
	(
		select rowno2, urlaliasnm
			from #taxonomy_rows t
		where exists (select 'x' from UrlAliasMapping map where map.urlaliasnm = t.urlaliasnm and
						map.Languageid = t.Languageid and
						map.SiteID = t.SiteID)
	)
	update tax
		set urlaliasnm = dbo.cms_UrlAliasResolveTitle(tax.urlaliasnm,tax.UrlAliasConfigId,tax.rowno2)
	from #taxonomy_rows tax
	inner join CheckForDuplicateAliasName CFD
	 on CFD.UrlAliasMappingId = tax.rowno2
	  ;
	
	insert into dbo.UrlAliasMapping (UrlAliasMappingId, UrlAliasConfigId, urlaliasnm, urltargetnm, Languageid, SiteID, TargetID, NodeID, AliasTypeID, IsEnabled)
	select 
		rowno2 as UrlAliasMappingId,
		urlaliasconfigid, 
		urlaliasnm, 
		urltargetnm, 
		languageid, 
		siteid, 
		targetid, 
		nodeid, 
		aliastypeid,
		IsEnabled
	from #taxonomy_rows;
	
	drop table #taxonomies_with_content;
	drop table #closest_config;
	drop table #taxonomy_rows;

end
go

/* End: Escalation 25201 - Auto alias not removed after the taxonomy is removed from the content 
================================================================================================*/
